==> dimensional-anchor-52.0.4.jar: src/immibis/chunkloader/porting/ChunkLoadInterface132.java <==
package immibis.chunkloader.porting;

import immibis.chunkloader.DimensionalAnchors;
import immibis.chunkloader.WorldInfo;
import immibis.core.Config;

import java.lang.reflect.Field;
import java.util.List;
import java.util.Map;

import net.minecraft.server.management.PlayerInstance;
import net.minecraft.server.management.PlayerManager;
import net.minecraft.world.ChunkCoordIntPair;
import net.minecraft.world.World;
import net.minecraft.world.WorldServer;
import net.minecraftforge.common.ForgeChunkManager;
import net.minecraftforge.common.ForgeChunkManager.LoadingCallback;
import net.minecraftforge.common.ForgeChunkManager.Ticket;
import net.minecraftforge.common.ForgeChunkManager.Type;
import cpw.mods.fml.common.Loader;

public class ChunkLoadInterface132 extends ChunkLoadInterface implements LoadingCallback {
	
	private static Field getField(Class<?> clazz, String name) throws NoSuchFieldException, SecurityException {
		Field f = clazz.getDeclaredField(name);
		f.setAccessible(true);
		return f;
	}
	
	@SuppressWarnings("unchecked")
	public ChunkLoadInterface132() {
		boolean bypassForgeLimits = Config.getBoolean("chunkloader.bypassForgeChunkLimits", true);
		
		if(bypassForgeLimits) {
			try {
				boolean overridesEnabled = getField(ForgeChunkManager.class, "overridesEnabled").getBoolean(null);
				
				Map<String, Integer> ticketConstraints = (Map<String, Integer>)getField(ForgeChunkManager.class, "ticketConstraints").get(null);
				Map<String, Integer> chunkConstraints = (Map<String, Integer>)getField(ForgeChunkManager.class, "chunkConstraints").get(null);
				
				if(!overridesEnabled) {
					ticketConstraints.clear();
					chunkConstraints.clear();
					getField(ForgeChunkManager.class, "overridesEnabled").set(null, true);
				}
				
				String modid = Loader.instance().getModObjectList().inverse().get(DimensionalAnchors.instance).getModId();
				
				ticketConstraints.put(modid, Integer.MAX_VALUE);
				chunkConstraints.put(modid, Integer.MAX_VALUE);
				
				DimensionalAnchors.logger.info("Bypassed Forge chunk limits");
				
			} catch(Exception e) {
				throw new RuntimeException(e);
			}
		}
		
		ForgeChunkManager.setForcedChunkLoadingCallback(DimensionalAnchors.instance, this);
	}
	
	@Override
	public void ticketsLoaded(List<Ticket> tickets, World world) {
		for(Ticket t : tickets)
			ForgeChunkManager.releaseTicket(t);
	}
	
	@Override
	public void onLoadWorld(WorldInfo w) {
		DimensionalAnchors.logger.fine("Requesting chunk loading ticket for "+w.getName());
		w.cliData = ForgeChunkManager.requestTicket(DimensionalAnchors.instance, w.world, Type.NORMAL);
		if(w.cliData == null)
			throw new RuntimeException("Failed to get chunk loading ticket for "+w.getName());
	}
	
	@Override
	public void onUnloadWorld(WorldInfo w) {
		DimensionalAnchors.logger.fine("Releasing chunk loading ticket for "+w.getName());
		ForgeChunkManager.releaseTicket((Ticket)w.cliData);
	}
	
	@Override
	public void addChunk(WorldInfo w, ChunkCoordIntPair ccip) {
		ForgeChunkManager.forceChunk((Ticket)w.cliData, ccip);
	}
	
	@Override
	public void removeChunk(WorldInfo w, ChunkCoordIntPair ccip) {
		ForgeChunkManager.unforceChunk((Ticket)w.cliData, ccip);
		
		if(w.world instanceof WorldServer) { // should always be true
			WorldServer ws = (WorldServer)w.world;
			
			// bugfix: if no mods are forcing the chunk and no players are watching it, unload it
			if(!ForgeChunkManager.getPersistentChunksFor(w.world).containsKey(ccip)
				&& !arePlayersWatchingChunk(ws.getPlayerManager(), ccip.chunkXPos, ccip.chunkZPos)) {
				
				ws.theChunkProviderServer.unloadChunksIfNotNearSpawn(ccip.chunkXPos, ccip.chunkZPos);
			}
		}
	}
	
	public static boolean arePlayersWatchingChunk(PlayerManager pm, int x, int z) {
		PlayerInstance chunk = pm.getOrCreateChunkWatcher(x, z, false);
		if(chunk == null)
			return false;
		
		return !chunk.playersInChunk.isEmpty();
	}
}

==> dimensional-anchor-52.0.6.jar: src/immibis/chunkloader/porting/ChunkLoadInterface132.java <==
package immibis.chunkloader.porting;

import immibis.chunkloader.DimensionalAnchors;
import immibis.chunkloader.WorldInfo;
import immibis.core.Config;

import java.lang.reflect.Field;
import java.util.List;
import java.util.Map;

import net.minecraft.server.management.PlayerInstance;
import net.minecraft.server.management.PlayerManager;
import net.minecraft.world.ChunkCoordIntPair;
import net.minecraft.world.World;
import net.minecraft.world.WorldServer;
import net.minecraftforge.common.ForgeChunkManager;
import net.minecraftforge.common.ForgeChunkManager.LoadingCallback;
import net.minecraftforge.common.ForgeChunkManager.Ticket;
import net.minecraftforge.common.ForgeChunkManager.Type;
import cpw.mods.fml.common.Loader;

public class ChunkLoadInterface132 extends ChunkLoadInterface implements LoadingCallback {
	
	private static Field getField(Class<?> clazz, String name) throws NoSuchFieldException, SecurityException {
		Field f = clazz.getDeclaredField(name);
		f.setAccessible(true);
		return f;
	}
	
	@SuppressWarnings("unchecked")
	public ChunkLoadInterface132() {
		boolean bypassForgeLimits = Config.getBoolean("chunkloader.bypassForgeChunkLimits", true);
		
		if(bypassForgeLimits) {
			try {
				boolean overridesEnabled = getField(ForgeChunkManager.class, "overridesEnabled").getBoolean(null);
				
				Map<String, Integer> ticketConstraints = (Map<String, Integer>)getField(ForgeChunkManager.class, "ticketConstraints").get(null);
				Map<String, Integer> chunkConstraints = (Map<String, Integer>)getField(ForgeChunkManager.class, "chunkConstraints").get(null);
				
				if(!overridesEnabled) {
					ticketConstraints.clear();
					chunkConstraints.clear();
					getField(ForgeChunkManager.class, "overridesEnabled").set(null, true);
				}
				
				String modid = Loader.instance().getModObjectList().inverse().get(DimensionalAnchors.instance).getModId();
				
				ticketConstraints.put(modid, Integer.MAX_VALUE);
				chunkConstraints.put(modid, Integer.MAX_VALUE);
				
				DimensionalAnchors.logger.info("Bypassed Forge chunk limits");
				
			} catch(Exception e) {
				throw new RuntimeException(e);
			}
		}
		
		ForgeChunkManager.setForcedChunkLoadingCallback(DimensionalAnchors.instance, this);
	}
	
	@Override
	public void ticketsLoaded(List<Ticket> tickets, World world) {
		for(Ticket t : tickets)
			ForgeChunkManager.releaseTicket(t);
	}
	
	@Override
	public void onLoadWorld(WorldInfo w) {
		DimensionalAnchors.logger.fine("Requesting chunk loading ticket for "+w.getName());
		w.cliData = ForgeChunkManager.requestTicket(DimensionalAnchors.instance, w.world, Type.NORMAL);
		if(w.cliData == null)
			throw new RuntimeException("Failed to get chunk loading ticket for "+w.getName());
	}
	
	@Override
	public void onUnloadWorld(WorldInfo w) {
		DimensionalAnchors.logger.fine("World unloaded: "+w.getName());
		
		// too late to release the ticket, so we release it next time the world is loaded instead
		//ForgeChunkManager.releaseTicket((Ticket)w.cliData);
	}
	
	@Override
	public void addChunk(WorldInfo w, ChunkCoordIntPair ccip) {
		ForgeChunkManager.forceChunk((Ticket)w.cliData, ccip);
	}
	
	@Override
	public void removeChunk(WorldInfo w, ChunkCoordIntPair ccip) {
		ForgeChunkManager.unforceChunk((Ticket)w.cliData, ccip);
		
		if(w.world instanceof WorldServer) { // should always be true
			WorldServer ws = (WorldServer)w.world;
			
			// bugfix: if no mods are forcing the chunk and no players are watching it, unload it
			if(!ForgeChunkManager.getPersistentChunksFor(w.world).containsKey(ccip)
				&& !arePlayersWatchingChunk(ws.getPlayerManager(), ccip.chunkXPos, ccip.chunkZPos)) {
				
				ws.theChunkProviderServer.unloadChunksIfNotNearSpawn(ccip.chunkXPos, ccip.chunkZPos);
			}
		}
	}
	
	public static boolean arePlayersWatchingChunk(PlayerManager pm, int x, int z) {
		PlayerInstance chunk = pm.getOrCreateChunkWatcher(x, z, false);
		if(chunk == null)
			return false;
		
		return !chunk.playersInChunk.isEmpty();
	}
}
